==> xwiki-commons-test-component-4.5-sources.jar: org/xwiki/test/annotation/ComponentList.java <==
/*
 * See the NOTICE file distributed with this work for additional
 * information regarding copyright ownership.
 *
 * This is free software; you can redistribute it and/or modify it
 * under the terms of the GNU Lesser General Public License as
 * published by the Free Software Foundation; either version 2.1 of
 * the License, or (at your option) any later version.
 *
 * This software is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU
 * Lesser General Public License for more details.
 *
 * You should have received a copy of the GNU Lesser General Public
 * License along with this software; if not, write to the Free
 * Software Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA
 * 02110-1301 USA, or see the FSF site: http://www.fsf.org.
 */
package org.xwiki.test.annotation;

import java.lang.annotation.Documented;
import java.lang.annotation.Inherited;
import java.lang.annotation.Retention;
import java.lang.annotation.Target;

import static java.lang.annotation.ElementType.METHOD;
import static java.lang.annotation.ElementType.TYPE;
import static java.lang.annotation.RetentionPolicy.RUNTIME;

/**
 * Defines the list of components to register.
 *
 * @version $Id: dc3a92d2d957c2fdd6cf864dd7b68d2acb16814d $
 * @since 4.2M1
 */
@Documented
@Retention(RUNTIME)
@Target({ TYPE, METHOD })
@Inherited
public @interface ComponentList
{
    /**
     * @return
     */
    // TODO: I would have liked to put the following documentation in the @return javadoc annotation above:
    // " the list of component implementation classes for components to register". But Checkstyle is buggy, see:
    // http://sourceforge.net/tracker/?func=detail&atid=397078&aid=2685184&group_id=29721
    Class< ? >[] value() default { };
}

==> xwiki-commons-test-component-6.2-sources.jar: org/xwiki/test/annotation/ComponentList.java <==
/*
 * See the NOTICE file distributed with this work for additional
 * information regarding copyright ownership.
 *
 * This is free software; you can redistribute it and/or modify it
 * under the terms of the GNU Lesser General Public License as
 * published by the Free Software Foundation; either version 2.1 of
 * the License, or (at your option) any later version.
 *
 * This software is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU
 * Lesser General Public License for more details.
 *
 * You should have received a copy of the GNU Lesser General Public
 * License along with this software; if not, write to the Free
 * Software Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA
 * 02110-1301 USA, or see the FSF site: http://www.fsf.org.
 */
package org.xwiki.test.annotation;

import java.lang.annotation.Documented;
import java.lang.annotation.Inherited;
import java.lang.annotation.Retention;
import java.lang.annotation.Target;

import static java.lang.annotation.ElementType.METHOD;
import static java.lang.annotation.ElementType.TYPE;
import static java.lang.annotation.RetentionPolicy.RUNTIME;

/**
 * Defines the list of components to register.
 *
 * @version $Id: 19ec3965cd40f64f9f426c4b4c67d619f34b94fa $
 * @since 4.2M1
 */
@Documented
@Retention(RUNTIME)
@Target({ TYPE, METHOD })
@Inherited
public @interface ComponentList
{
    /**
     * @return
     */
    // TODO: I would have liked to put the following documentation in the @return javadoc annotation above:
    // " the list of component implementation classes for components to register".
    // But Checkstyle is buggy, see: http://sourceforge.net/tracker/?func=detail&atid=397078&aid=2685184&group_id=29721
    Class<?>[] value() default { };
}
